pub struct PreauthKey {
pub key: String,
pub acl_tags: Vec<String>,
}Expand description
A Headscale pre-authentication key for onboarding a new node.
Fields
key: StringThe key string to pass to tailscale up --auth-key=<key>.
ACL tags the new node will be advertised with.