pub async fn wait_ready(
endpoint: &ControlEndpoint,
timeout: Duration,
) -> ReadyOutcomeExpand description
Poll endpoint until the process reports ready, reports terminal, or the
timeout expires.
pub async fn wait_ready(
endpoint: &ControlEndpoint,
timeout: Duration,
) -> ReadyOutcomePoll endpoint until the process reports ready, reports terminal, or the
timeout expires.