pub struct DeviceReconciler { /* private fields */ }Expand description
Launches a component’s app on a device or simulator and supervises it.
Implementations
Sourceimpl DeviceReconciler
impl DeviceReconciler
pub fn new() -> Self
Sourcepub fn with_log_buf(self, log_buf: LogBuffer) -> Self
pub fn with_log_buf(self, log_buf: LogBuffer) -> Self
Stream into a caller-owned buffer, so it can be registered for polling
before up returns — same contract as LocalProcessReconciler.